@@ -39,7 +39,6 @@ gboolean seed_gvalue_from_seed_value (JSContextRef ctx,
 gboolean seed_gi_make_argument (JSContextRef ctx,
 				JSValueRef value,
 				GITypeInfo * type_info,
-				GIArgInfo * arg_info,
 				GArgument * arg, JSValueRef * exception);
 JSValueRef seed_gi_argument_make_js (JSContextRef ctx,
 				     GArgument * arg,
@@ -110,6 +109,16 @@ gdouble seed_value_to_double (JSContextRef ctx,
 JSValueRef seed_value_from_double (JSContextRef ctx,
 				   gdouble val, JSValueRef * exception);
 
+gsize seed_value_to_size (JSContextRef ctx,
+			  JSValueRef val, JSValueRef * exception);
+JSValueRef seed_value_from_size (JSContextRef ctx,
+				 gsize val, JSValueRef * exception);
+
+gssize seed_value_to_ssize (JSContextRef ctx,
+			    JSValueRef val, JSValueRef * exception);
+JSValueRef seed_value_from_ssize (JSContextRef ctx,
+				  gssize val, JSValueRef * exception);
+
 gchar *seed_value_to_filename (JSContextRef ctx,
 			       JSValueRef val, JSValueRef * exception);
 JSValueRef seed_value_from_filename (JSContextRef ctx,
